.. sng documentation master file, created by
   sphinx-quickstart on Sun Dec  2 07:50:06 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to sng's documentation!
===============================

The ``sng`` package (short for "Startup Name Generator") is hosted `on GitHub <https://github.com/AlexEngelhardt/startup-name-generator>`_. This is its documentation.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   introduction
   installation
   notebooks/01_quickstart.ipynb
   discussion
   modules


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
